macro_rules! test_context {
($python_version:expr) => { ... };
}Expand description
Create a new TestContext with the given Python version.
Creates a virtual environment for the test.
Resolves the uv binary path at runtime via get_bin!.
macro_rules! test_context {
($python_version:expr) => { ... };
}Create a new TestContext with the given Python version.
Creates a virtual environment for the test.
Resolves the uv binary path at runtime via get_bin!.