uv_snapshot

Macro uv_snapshot 

macro_rules! uv_snapshot {
    ($spawnable:expr, @$snapshot:literal) => { ... };
    ($filters:expr, $spawnable:expr, @$snapshot:literal) => { ... };
    ($filters:expr, $spawnable:expr, input=$input:expr, @$snapshot:literal) => { ... };
    ($filters:expr, windows_filters=false, $spawnable:expr, @$snapshot:literal) => { ... };
    ($filters:expr, universal_windows_filters=true, $spawnable:expr, @$snapshot:literal) => { ... };
}
Run [assert_cmd_snapshot!], with default filters or with custom filters.

By default, the filters will search for the generally windows-only deps colorama and tzdata, filter them out and decrease the package counts by one for each match.